@@ -8,10 +8,10 @@ class WeakFunctionReferences:
 
     def add(self, function: typing.Callable):
         try:
-            _id = function.__self__
+            _id = id(function.__self__)
         except:
-            _id = function
-        callback_id = hash("%s%s" % (id(_id), function.__name__)) & 0xffffffffffff
+            _id = id(function)
+        callback_id = (_id ^ hash(function.__name__)) & 0xffffffffffff
         if callback_id in self.references:
             return callback_id
         self.references[callback_id] = weakref.WeakMethod(function, self._create_delete_callback(callback_id))
@@ -19,11 +19,10 @@ class WeakFunctionReferences:
 
     def remove(self, function: typing.Callable):
         try:
-            _id = function.__self__
+            _id = id(function.__self__)
         except:
-            _id = function
-        callback_id = hash("%s%s" % (id(_id), function.__name__)) & 0xffffffffffff
-        del self.references[callback_id]
+            _id = id(function)
+        del self.references[(_id ^ hash(function.__name__)) & 0xffffffffffff]
 
     def get(self, callback_id: int) -> typing.Callable:
         return self.references[callback_id]()
